==> react-redux-grid-1.2.0.tgz: package/test/components/plugins/pager/toolbar/Button.test.js <==
/* global sinon */
import expect from 'expect';
import React from 'react';
import { shallow } from 'enzyme';
import { Button } from './../../../../../src/components/plugins/pager/toolbar/Button.jsx';
import * as ButtonUtils from './../../../../../src/components/plugins/pager/toolbar/Button.jsx';
import { mockStore } from './../../../../testUtils/index';
import { localGridData } from './../../../../testUtils/data';

const store = mockStore();

store.subscribe = () => {};

const props = {
    store,
    pageSize: 25,
    dataSource: localGridData,
    ref: 'pagertoolbar',
    plugins: {
        PAGER: {
            enabled: true
        }
    }
};

describe('A Pager Toolbar Next Button', () => {

    const nextButtonProps = Object.assign(props, { type: 'NEXT' });

    const component = shallow(<Button { ...nextButtonProps } />);

    it('Should button to be a Next Button', () => {
        expect(component.text()).toEqual('Next');
    });

    it('Should have the right class', () => {
        expect(component.props().className).toEqual('react-grid-page-buttons react-grid-next');
    });

    it('Shouldn\'t be diabled', () => {
        expect(component.props().disabled).toEqual(false);
    });
});

describe('handleButtonClick function with local paging', () => {
    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const dataSource = 'url/to/dataSource';
    const plugins = {
        PAGER: {
            pagingType: 'local'
        }
    };
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };
    const localPagedStore = mockStore(null, { pageIndex: 1, type: 'PAGE_LOCAL' });

    it('The action should reflect the next page when clicked', () => {
        expect(
            ButtonUtils.handleButtonClick(type, pageIndex, pageSize, dataSource, BUTTON_TYPES, plugins, localPagedStore)
        ).toEqual(undefined);
    });
});

describe('handleButtonClick function with remote paging', () => {
    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const dataSource = 'url/to/dataSource';
    const plugins = {
        PAGER: {
            pagingType: 'remote'
        }
    };
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };
    const localPagedStore = mockStore(null, { state: true, type: 'SET_LOADING_STATE' });

    it('The action should reflect a loading state when clicking next with a remote pager', () => {
        expect(
            ButtonUtils.handleButtonClick(type, pageIndex, pageSize, dataSource, BUTTON_TYPES, plugins, localPagedStore)
        ).toEqual(undefined);
    });
});

describe('handleButtonClick function without a pagingType specified', () => {
    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const dataSource = 'url/to/dataSource';
    const plugins = {
        PAGER: {}
    };
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };
    const uncalledStore = mockStore(null);

    uncalledStore.dispatch = sinon.spy();

    it('Should not dispatch an action', () => {
        expect(
            ButtonUtils.handleButtonClick(
                type, pageIndex, pageSize, dataSource, BUTTON_TYPES, plugins, uncalledStore
            )
        ).toEqual(undefined);
    });

    it('Should not have fired a store event', () => {
        expect(
            uncalledStore.dispatch.called
        ).toBe(false);
    });
});

describe('isButtonDisabled function', () => {

    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const currentRecords = 1000;
    const total = 100;
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };

    it('Should be disabled if theres more visible records than the total', () => {
        expect(
            ButtonUtils.isButtonDisabled(type, pageIndex, pageSize,
                currentRecords, total, BUTTON_TYPES)
        ).toEqual(false);
    });

    it('Should be disabled if theres equal number of visible records to the total', () => {
        expect(
            ButtonUtils.isButtonDisabled(type, 1, 100,
                100, total, BUTTON_TYPES)
        ).toEqual(false);
    });

    it('Back button should be disabled if were on page index 0', () => {
        expect(
            ButtonUtils.isButtonDisabled('BACK', pageIndex, pageSize,
                currentRecords, total, BUTTON_TYPES)
        ).toEqual(true);
    });

    it('Back button should be enabled if were on page index 1', () => {
        expect(
            ButtonUtils.isButtonDisabled('BACK', 1, pageSize,
                currentRecords, total, BUTTON_TYPES)
        ).toEqual(false);
    });
});

==> react-redux-grid-4.4.6.tgz: package/test/components/plugins/pager/toolbar/Button.test.js <==
/* global sinon */
import expect from 'expect';
import React from 'react';
import { shallow } from 'enzyme';
import { Button } from './../../../../../src/components/plugins/pager/toolbar/Button.jsx';
import * as ButtonUtils from './../../../../../src/components/plugins/pager/toolbar/Button.jsx';
import { mockStore } from './../../../../testUtils/index';
import { localGridData } from './../../../../testUtils/data';

const store = mockStore();

const stateKey = 'stateKey';

store.subscribe = () => {};

const props = {
    store,
    pageSize: 25,
    dataSource: localGridData,
    ref: 'pagertoolbar',
    plugins: {
        PAGER: {
            enabled: true
        }
    }
};

describe('A Pager Toolbar Next Button', () => {

    const nextButtonProps = Object.assign(props, { type: 'NEXT' });

    const component = shallow(<Button { ...nextButtonProps } />);

    it('Should button to be a Next Button', () => {
        expect(component.text()).toEqual('Next');
    });

    it('Should have the right class', () => {
        expect(component.props().className).toEqual('react-grid-page-buttons react-grid-next');
    });

    it('Shouldn\'t be diabled', () => {
        expect(component.props().disabled).toEqual(false);
    });
});

describe('handleButtonClick function with local paging', () => {
    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const dataSource = 'url/to/dataSource';
    const plugins = {
        PAGER: {
            pagingType: 'local'
        }
    };
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };
    const localPagedStore = mockStore(null, { pageIndex: 1, type: 'PAGE_LOCAL' });

    it('The action should reflect the next page when clicked', () => {
        expect(
            ButtonUtils.handleButtonClick(
                type, pageIndex, pageSize, dataSource, BUTTON_TYPES, plugins, stateKey, localPagedStore
            )
        ).toEqual(undefined);
    });
});

describe('handleButtonClick function with remote paging', () => {
    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const dataSource = 'url/to/dataSource';
    const plugins = {
        PAGER: {
            pagingType: 'remote'
        }
    };
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };
    const localPagedStore = mockStore(null, { state: true, type: 'SET_LOADING_STATE' });

    it('The action should reflect a loading state when clicking next with a remote pager', () => {
        expect(
            ButtonUtils.handleButtonClick(
                type, pageIndex, pageSize, dataSource, BUTTON_TYPES, plugins, stateKey, localPagedStore
            )
        ).toEqual(undefined);
    });
});

describe('handleButtonClick function without a pagingType specified', () => {
    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const dataSource = 'url/to/dataSource';
    const plugins = {
        PAGER: {}
    };
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };
    const uncalledStore = mockStore(null);

    uncalledStore.dispatch = sinon.spy();

    it('Should not dispatch an action', () => {
        expect(
            ButtonUtils.handleButtonClick(
                type, pageIndex, pageSize, dataSource, BUTTON_TYPES, plugins, stateKey, uncalledStore
            )
        ).toEqual(undefined);
    });

    it('Should not have fired a store event', () => {
        expect(
            uncalledStore.dispatch.called
        ).toBe(false);
    });
});

describe('isButtonDisabled function', () => {

    const type = 'NEXT';
    const pageIndex = 0;
    const pageSize = 25;
    const currentRecords = 1000;
    const total = 100;
    const BUTTON_TYPES = {
        NEXT: 'NEXT',
        BACK: 'BACK'
    };

    it('Should be disabled if theres more visible records than the total', () => {
        expect(
            ButtonUtils.isButtonDisabled(type, pageIndex, pageSize,
                currentRecords, total, BUTTON_TYPES)
        ).toEqual(false);
    });

    it('Should be disabled if theres equal number of visible records to the total', () => {
        expect(
            ButtonUtils.isButtonDisabled(type, 1, 100,
                100, total, BUTTON_TYPES)
        ).toEqual(false);
    });

    it('Back button should be disabled if were on page index 0', () => {
        expect(
            ButtonUtils.isButtonDisabled('BACK', pageIndex, pageSize,
                currentRecords, total, BUTTON_TYPES)
        ).toEqual(true);
    });

    it('Back button should be enabled if were on page index 1', () => {
        expect(
            ButtonUtils.isButtonDisabled('BACK', 1, pageSize,
                currentRecords, total, BUTTON_TYPES)
        ).toEqual(false);
    });
});
